@@ -16,5 +16,5 @@ print "ok 1--MARC::Errorchecks loaded\n";
 
 print "Please run: t/008errorchecks.t.pl, t/check_010.t, and t/Errorchecks.t\n";
 
-print "Press Enter to quit";
-<>;
\ No newline at end of file
+#print "Press Enter to quit";
+#<>;
\ No newline at end of file
